netapp_ontap.models.lun_copy_destinations_progress API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_copy_destinations_progress`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunCopyDestinationsProgressSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunCopyDestinationsProgress object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `elapsed: Size GET`

    The amount of time that has elapsed since the start of the LUN copy, in seconds.

  `failure: Error GET`

    Error information provided if the asynchronous LUN copy operation fails.

  `percent_complete: Size GET`

    The percentage completed of the LUN copy.

  `state: str GET`

    The state of the LUN copy.

    Valid choices:

    - preparing
    - replicating
    - paused
    - paused_error
    - complete
    - reverting
    - failed
  `volume_snapshot_blocked: bool GET`

    This property reports if volume snapshots are blocked by the LUN copy. This property can be polled to identify when volume snapshots can be resumed after beginning a LUN copy.